@@ -20,8 +20,6 @@ try:
     import pixplot
 
 except BaseException as e:
-    print("Keras Tensorflor Backend Failled With Error: ", e)
-    print("Using most recent tensorflow keras backend...")
     install('pixplot')
     import pixplot
 
@@ -1071,7 +1069,7 @@ def write_images(**kwargs):
 
 def get_version():
     '''Return the version of pixplot installed'''
-    return pkg_resources.get_distribution('pixplot').version
+    return pkg_resources.get_distribution('JATA').version
 
 
 class Image:
